==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkProp3DAxisFollower.java <==
// java wrapper for vtkProp3DAxisFollower object
//

package vtk;
import vtk.*;

public class vtkProp3DAxisFollower extends vtkProp3DFollower
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAxis_2(vtkAxisActor id0);
  public void SetAxis(vtkAxisActor id0)
    { SetAxis_2(id0); }

  private native long GetAxis_3();
  public vtkAxisActor GetAxis() {
    long temp = GetAxis_3();

    if (temp == 0) return null;
    return (vtkAxisActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetAutoCenter_4(int id0);
  public void SetAutoCenter(int id0)
    { SetAutoCenter_4(id0); }

  private native int GetAutoCenter_5();
  public int GetAutoCenter()
    { return GetAutoCenter_5(); }

  private native void AutoCenterOn_6();
  public void AutoCenterOn()
    { AutoCenterOn_6(); }

  private native void AutoCenterOff_7();
  public void AutoCenterOff()
    { AutoCenterOff_7(); }

  private native void SetEnableDistanceLOD_8(int id0);
  public void SetEnableDistanceLOD(int id0)
    { SetEnableDistanceLOD_8(id0); }

  private native int GetEnableDistanceLOD_9();
  public int GetEnableDistanceLOD()
    { return GetEnableDistanceLOD_9(); }

  private native void SetDistanceLODThreshold_10(double id0);
  public void SetDistanceLODThreshold(double id0)
    { SetDistanceLODThreshold_10(id0); }

  private native double GetDistanceLODThresholdMinValue_11();
  public double GetDistanceLODThresholdMinValue()
    { return GetDistanceLODThresholdMinValue_11(); }

  private native double GetDistanceLODThresholdMaxValue_12();
  public double GetDistanceLODThresholdMaxValue()
    { return GetDistanceLODThresholdMaxValue_12(); }

  private native double GetDistanceLODThreshold_13();
  public double GetDistanceLODThreshold()
    { return GetDistanceLODThreshold_13(); }

  private native void SetEnableViewAngleLOD_14(int id0);
  public void SetEnableViewAngleLOD(int id0)
    { SetEnableViewAngleLOD_14(id0); }

  private native int GetEnableViewAngleLOD_15();
  public int GetEnableViewAngleLOD()
    { return GetEnableViewAngleLOD_15(); }

  private native void SetViewAngleLODThreshold_16(double id0);
  public void SetViewAngleLODThreshold(double id0)
    { SetViewAngleLODThreshold_16(id0); }

  private native double GetViewAngleLODThresholdMinValue_17();
  public double GetViewAngleLODThresholdMinValue()
    { return GetViewAngleLODThresholdMinValue_17(); }

  private native double GetViewAngleLODThresholdMaxValue_18();
  public double GetViewAngleLODThresholdMaxValue()
    { return GetViewAngleLODThresholdMaxValue_18(); }

  private native double GetViewAngleLODThreshold_19();
  public double GetViewAngleLODThreshold()
    { return GetViewAngleLODThreshold_19(); }

  private native void SetScreenOffset_20(double id0);
  public void SetScreenOffset(double id0)
    { SetScreenOffset_20(id0); }

  private native double GetScreenOffset_21();
  public double GetScreenOffset()
    { return GetScreenOffset_21(); }

  private native void ComputeMatrix_22();
  public void ComputeMatrix()
    { ComputeMatrix_22(); }

  private native void ShallowCopy_23(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_23(id0); }

  private native double AutoScale_24(vtkViewport id0,vtkCamera id1,double id2,double id3[]);
  public double AutoScale(vtkViewport id0,vtkCamera id1,double id2,double id3[])
    { return AutoScale_24(id0,id1,id2,id3); }

  private native int RenderOpaqueGeometry_25(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_25(id0); }

  private native int RenderTranslucentPolygonalGeometry_26(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_26(id0); }

  private native int RenderVolumetricGeometry_27(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_27(id0); }

  private native void SetViewport_28(vtkViewport id0);
  public void SetViewport(vtkViewport id0)
    { SetViewport_28(id0); }

  private native long GetViewport_29();
  public vtkViewport GetViewport() {
    long temp = GetViewport_29();

    if (temp == 0) return null;
    return (vtkViewport)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkProp3DAxisFollower() { super(); }

  public vtkProp3DAxisFollower(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-aarch64.pkg.tar.xz: vtk/vtkProp3DAxisFollower.java <==
// java wrapper for vtkProp3DAxisFollower object
//

package vtk;
import vtk.*;

public class vtkProp3DAxisFollower extends vtkProp3DFollower
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAxis_2(vtkAxisActor id0);
  public void SetAxis(vtkAxisActor id0)
    { SetAxis_2(id0); }

  private native long GetAxis_3();
  public vtkAxisActor GetAxis() {
    long temp = GetAxis_3();

    if (temp == 0) return null;
    return (vtkAxisActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAutoCenter_4(int id0);
  public void SetAutoCenter(int id0)
    { SetAutoCenter_4(id0); }

  private native int GetAutoCenter_5();
  public int GetAutoCenter()
    { return GetAutoCenter_5(); }

  private native void AutoCenterOn_6();
  public void AutoCenterOn()
    { AutoCenterOn_6(); }

  private native void AutoCenterOff_7();
  public void AutoCenterOff()
    { AutoCenterOff_7(); }

  private native void SetEnableDistanceLOD_8(int id0);
  public void SetEnableDistanceLOD(int id0)
    { SetEnableDistanceLOD_8(id0); }

  private native int GetEnableDistanceLOD_9();
  public int GetEnableDistanceLOD()
    { return GetEnableDistanceLOD_9(); }

  private native void SetDistanceLODThreshold_10(double id0);
  public void SetDistanceLODThreshold(double id0)
    { SetDistanceLODThreshold_10(id0); }

  private native double GetDistanceLODThresholdMinValue_11();
  public double GetDistanceLODThresholdMinValue()
    { return GetDistanceLODThresholdMinValue_11(); }

  private native double GetDistanceLODThresholdMaxValue_12();
  public double GetDistanceLODThresholdMaxValue()
    { return GetDistanceLODThresholdMaxValue_12(); }

  private native double GetDistanceLODThreshold_13();
  public double GetDistanceLODThreshold()
    { return GetDistanceLODThreshold_13(); }

  private native void SetEnableViewAngleLOD_14(int id0);
  public void SetEnableViewAngleLOD(int id0)
    { SetEnableViewAngleLOD_14(id0); }

  private native int GetEnableViewAngleLOD_15();
  public int GetEnableViewAngleLOD()
    { return GetEnableViewAngleLOD_15(); }

  private native void SetViewAngleLODThreshold_16(double id0);
  public void SetViewAngleLODThreshold(double id0)
    { SetViewAngleLODThreshold_16(id0); }

  private native double GetViewAngleLODThresholdMinValue_17();
  public double GetViewAngleLODThresholdMinValue()
    { return GetViewAngleLODThresholdMinValue_17(); }

  private native double GetViewAngleLODThresholdMaxValue_18();
  public double GetViewAngleLODThresholdMaxValue()
    { return GetViewAngleLODThresholdMaxValue_18(); }

  private native double GetViewAngleLODThreshold_19();
  public double GetViewAngleLODThreshold()
    { return GetViewAngleLODThreshold_19(); }

  private native double GetScreenOffset_20();
  public double GetScreenOffset()
    { return GetScreenOffset_20(); }

  private native void SetScreenOffset_21(double id0);
  public void SetScreenOffset(double id0)
    { SetScreenOffset_21(id0); }

  private native void SetScreenOffsetVector_22(double id0,double id1);
  public void SetScreenOffsetVector(double id0,double id1)
    { SetScreenOffsetVector_22(id0,id1); }

  private native void SetScreenOffsetVector_23(double id0[]);
  public void SetScreenOffsetVector(double id0[])
    { SetScreenOffsetVector_23(id0); }

  private native double[] GetScreenOffsetVector_24();
  public double[] GetScreenOffsetVector()
    { return GetScreenOffsetVector_24(); }

  private native void ComputeMatrix_25();
  public void ComputeMatrix()
    { ComputeMatrix_25(); }

  private native void ShallowCopy_26(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_26(id0); }

  private native double AutoScale_27(vtkViewport id0,vtkCamera id1,double id2,double id3[]);
  public double AutoScale(vtkViewport id0,vtkCamera id1,double id2,double id3[])
    { return AutoScale_27(id0,id1,id2,id3); }

  private native int RenderOpaqueGeometry_28(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_28(id0); }

  private native int RenderTranslucentPolygonalGeometry_29(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_29(id0); }

  private native int RenderVolumetricGeometry_30(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_30(id0); }

  private native void SetViewport_31(vtkViewport id0);
  public void SetViewport(vtkViewport id0)
    { SetViewport_31(id0); }

  private native long GetViewport_32();
  public vtkViewport GetViewport() {
    long temp = GetViewport_32();

    if (temp == 0) return null;
    return (vtkViewport)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkProp3DAxisFollower() { super(); }

  public vtkProp3DAxisFollower(long id) { super(id); }
  public native long   VTKInit();

}
